import { Utilities } from '@/util/Utilities';
import {
    Form, Grid, Modal, ModalService, Select, TextInput, Text, Button, DialogService, LoadingService, Textarea,
} from '@zeedhi/common';
import {
    Http, IDictionary, IEventParam, MemoryDatasource, Metadata,
} from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import {
    ZdFooter,
    ZdForm, ZdRow, ZdSelect, ZdText, ZdTextInput,
} from '@zeedhi/vuetify';

export class AtividadeCdaController {
    public visibilidade: boolean = true;

    private geraDocumentoModal!: Modal;

    public currentRow: any = {};

    public rowGeraDocumento: any = {};

    public campofilter: any = {};

    get visibilidadeDoFrame() {
        return !this.visibilidade;
    }

    get disabled(): boolean {
        const grid = Metadata.getInstance<Grid>('cda-tek-grid');
        return grid.selectedRows.length <= 0;
    }

    public voltarPaginaInicial() {
        this.visibilidade = true;
    }

    public expandir({ component }: any) {
        const form = Metadata.getInstance<Form>(component.name.split('_')[1]);
        form.isVisible = !form.isVisible;
        component.iconName = (component.iconName === 'mdi-chevron-down') ? 'mdi-chevron-right' : 'mdi-chevron-down';
    }

    public visualizarAtividade({ row }: any) {
        this.visibilidade = false;
        this.currentRow = row;
        this.montarInformacoesAtividade();
    }

    public async exibirModalGeraDoc() {
        this.geraDocumentoModal = await ModalService.createFromJson('sm_cda/Modal/gerar_documento_cda', true);
        this.geraDocumentoModal.show();
    }

    public fecharModalGeraDoc() {
        this.geraDocumentoModal.hide();
        this.geraDocumentoModal?.destroy();
    }

    public async abrirModalGeraDoc() {
        await this.exibirModalGeraDoc();
        Metadata.getInstance<Text>('titleText').text = 'Gerar Documento';
    }

    public dialogGerarDocumento({ row }: IEventParam<Button>) {
        this.rowGeraDocumento = row;
        DialogService.show({
            name: 'dialog-deletar-anexo',
            type: 'warning',
            title: 'Atenção',
            text: 'Deseja gerar o documento da atividade?',
            buttons: [
                {
                    name: 'NAO',
                    component: 'ZdButton',
                    label: 'Não',
                    outline: true,
                    events: {
                        click: () => {
                            DialogService.hide();
                        },
                    },
                },
                {
                    name: 'SIM',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: () => {
                            this.abrirModalGeraDoc();
                            DialogService.hide();
                        },
                    },
                },
            ],
        });
    }

    public montarInformacoesAtividade() {
        Metadata.getInstance<ZdText>('titulo-agrupamento-info-atividade').text = this.currentRow.DATA;
        const tipoLacamento = this.currentRow.IDSERVPREST;
        
        if (tipoLacamento === null || tipoLacamento === '') {
            Metadata.getInstance<Select>('tipoLacamento-atividade-cda-tipolacamento').value = '';
        } else {
            Metadata.getInstance<Button>('button-cda-lacamento-atividade-incluir').disabled = false;
            Metadata.getInstance<Select>('tipoLacamento-atividade-cda-tipolacamento').value = tipoLacamento;
            this.ativaCampoPorTipoDeLacamento();
            this.carregarDadosAtividade();
        }
    }

    public ativaCampoPorTipoDeLacamento() {
        this.redefinirFormulario();
        this.defineGridHorasNaoFaturadas();
        const tipoLancamento = Metadata.getInstance<ZdSelect>('tipoLacamento-atividade-cda-tipolacamento').value;
        const rowDescricaoLacamento = Metadata.getInstance<ZdRow>('row-descricao-lacamento-cda');
        const formDescricaoLacamento = Metadata.getInstance<ZdForm>('form-descricao-lacamento-cda-editLacamento');
        
        switch (tipoLancamento) {
            case 'ATIVIDADE_CLIENTE':
                rowDescricaoLacamento.isVisible = true;
                formDescricaoLacamento.isVisible = true;
                Metadata.getInstance<ZdRow>('row-identificacao-atividade-cliente-cda').isVisible = true;
                Metadata.getInstance<ZdForm>('form-identificacao-atividade-cliente-cda-editLacamento').isVisible = true;
                Metadata.getInstance<ZdRow>('row-registro-de-horas-lancamento-cda').isVisible = true;
                Metadata.getInstance<ZdForm>('form-registro-de-horas-cda-editLacamento').isVisible = true;
                break;
            case 'VISITA_PROSPECT':
                rowDescricaoLacamento.isVisible = true;
                formDescricaoLacamento.isVisible = true;
                Metadata.getInstance<ZdRow>('row-identificacao-visita-prospect-cda').isVisible = true;
                Metadata.getInstance<ZdForm>('form-identificacao-visita-prospect-cda-editLacamento').isVisible = true;
                Metadata.getInstance<ZdRow>('row-contato-lancamento-cda').isVisible = true;
                Metadata.getInstance<ZdForm>('form-contato-lancamento-cda-editLacamento').isVisible = true;
                Metadata.getInstance<ZdRow>('row-registro-de-horas-lancamento-cda').isVisible = true;
                Metadata.getInstance<ZdForm>('form-registro-de-horas-cda-editLacamento').isVisible = true;
                break;
            case 'RELACIONAMENTO_CLIENTE':
                rowDescricaoLacamento.isVisible = true;
                formDescricaoLacamento.isVisible = true;
                Metadata.getInstance<ZdRow>('row-identificacao-relacionamento-cliente-cda').isVisible = true;
                Metadata.getInstance<ZdForm>('form-identificacao-relacionamento-cliente-cda-editLacamento').isVisible = true;
                Metadata.getInstance<ZdRow>('row-contato-lancamento-cda').isVisible = true;
                Metadata.getInstance<ZdForm>('form-contato-lancamento-cda-editLacamento').isVisible = true;
                Metadata.getInstance<ZdRow>('row-registro-de-horas-lancamento-cda').isVisible = true;
                Metadata.getInstance<ZdForm>('form-registro-de-horas-cda-editLacamento').isVisible = true;
                break;
            case 'FALTA_JUSTIFICADA':
                Metadata.getInstance<ZdRow>('row-justificativa-lancamento-cda').isVisible = true;
                Metadata.getInstance<ZdForm>('form-justificativa-lacamento-cda-editLacamento').isVisible = true;
                break;
            case 'ATIVIDADE_INTERNA':
            case 'FERIAS':
            case 'FALTA_NAO_JUSTIFICADA':
                break;
            case 'AFASTAMENTO_INSS':
                Metadata.getInstance<ZdRow>('row-justificativa-lancamento-cda').isVisible = true;
                Metadata.getInstance<ZdForm>('form-justificativa-afastamentoinss-lacamento-cda-editLacamento').isVisible = true;
                break;
            default:
                break;
        }
        Metadata.getInstance<ZdFooter>('footer-vizualizacao-atividade').isVisible = true;
    }

    public async carregarDadosAtividade() {
        const tipoLancamento = Metadata.getInstance<ZdSelect>('tipoLacamento-atividade-cda-tipolacamento').value;

        switch (tipoLancamento) {
            case 'ATIVIDADE_CLIENTE':
                Metadata.getInstance<Select>('identificacao-atividade-cliente-cda-cliente').value = this.currentRow.CDCLIENTE;
                Metadata.getInstance<Select>('identificacao-atividade-cliente-cda-representante').value = this.currentRow.CDCLIENTE;
                Metadata.getInstance<Select>('identificacao-atividade-cliente-cda-local').value = this.currentRow.NRPROPOSFAS;
                Metadata.getInstance<Select>('identificacao-atividade-cliente-cda-projeto').value = this.currentRow.CDCLIENTE;
                Metadata.getInstance<Select>('identificacao-atividade-cliente-cda-atividade').value = this.currentRow.CDTIPOSERV;
                break;
            case 'VISITA_PROSPECT':
                Metadata.getInstance<Select>('identificacao-visita-prospect-cda-prospect').value = this.currentRow.CDPROSPECT;
                Metadata.getInstance<Select>('identificacao-visita-prospect-cda-intelocutor-prospect').value = this.currentRow.CDINTEPROS;
                break;
            case 'RELACIONAMENTO_CLIENTE':
                Metadata.getInstance<Select>('identificacao-visita-prospect-cda-prospect').value = this.currentRow.CDCLIENTE;
                Metadata.getInstance<Select>('identificacao-visita-prospect-cda-intelocutor-prospect').value = this.currentRow.CDINTECLIE;
                break;
            case 'FALTA_JUSTIFICADA':
                Metadata.getInstance<Select>('justificativa-lacamento-cda').value = this.currentRow.NRMOTIVOEXCEFREQ;
                break;
            case 'ATIVIDADE_INTERNA':
            case 'FERIAS':
            case 'FALTA_NAO_JUSTIFICADA':
                break;
            case 'AFASTAMENTO_INSS':
                Metadata.getInstance<Select>('justificativa-lacamento-afastamentoinss-cda').value = this.currentRow.NRMOTIVOEXCEFREQ;
                break;
            default:
                break;
        }
    }

    public limparCampos() {
        Metadata.getInstance<Form>('form-descricao-lacamento-cda-editLacamento').clearForm();
        Metadata.getInstance<Form>('form-identificacao-atividade-cliente-cda-editLacamento').clearForm();
        Metadata.getInstance<Form>('form-identificacao-visita-prospect-cda-editLacamento').clearForm();
        Metadata.getInstance<Form>('form-contato-lancamento-cda-editLacamento').clearForm();
        Metadata.getInstance<Form>('form-identificacao-relacionamento-cliente-cda-editLacamento').clearForm();
        Metadata.getInstance<Form>('form-contato-lancamento-cda-editLacamento').clearForm();
        Metadata.getInstance<Form>('form-justificativa-lacamento-cda-editLacamento').clearForm();
        Metadata.getInstance<Form>('form-justificativa-afastamentoinss-lacamento-cda-editLacamento').clearForm();
        Metadata.getInstance<Form>('form-registro-de-horas-cda-editLacamento').clearForm();
    }

    public redefinirFormulario() {
        Metadata.getInstance<ZdRow>('row-descricao-lacamento-cda').isVisible = false;
        Metadata.getInstance<ZdForm>('form-descricao-lacamento-cda-editLacamento').isVisible = false;
        Metadata.getInstance<ZdRow>('row-identificacao-atividade-cliente-cda').isVisible = false;
        Metadata.getInstance<ZdForm>('form-identificacao-atividade-cliente-cda-editLacamento').isVisible = false;
        Metadata.getInstance<ZdRow>('row-identificacao-visita-prospect-cda').isVisible = false;
        Metadata.getInstance<ZdForm>('form-identificacao-visita-prospect-cda-editLacamento').isVisible = false;
        Metadata.getInstance<ZdRow>('row-contato-lancamento-cda').isVisible = false;
        Metadata.getInstance<ZdForm>('form-contato-lancamento-cda-editLacamento').isVisible = false;
        Metadata.getInstance<ZdRow>('row-identificacao-relacionamento-cliente-cda').isVisible = false;
        Metadata.getInstance<ZdForm>('form-identificacao-relacionamento-cliente-cda-editLacamento').isVisible = false;
        Metadata.getInstance<ZdRow>('row-contato-lancamento-cda').isVisible = false;
        Metadata.getInstance<ZdForm>('form-contato-lancamento-cda-editLacamento').isVisible = false;
        Metadata.getInstance<ZdRow>('row-justificativa-lancamento-cda').isVisible = false;
        Metadata.getInstance<ZdForm>('form-justificativa-lacamento-cda-editLacamento').isVisible = false;
        Metadata.getInstance<ZdForm>('form-justificativa-afastamentoinss-lacamento-cda-editLacamento').isVisible = false;
        Metadata.getInstance<ZdRow>('row-registro-de-horas-lancamento-cda').isVisible = false;
        Metadata.getInstance<ZdForm>('form-registro-de-horas-cda-editLacamento').isVisible = false;
        Metadata.getInstance<ZdFooter>('footer-vizualizacao-atividade').isVisible = false;
        this.limparCampos();
    }

    public setParametrosForms({ component }: any) {
        const representante = Metadata.getInstance<Select>('identificacao-atividade-cliente-cda-representante');
        const proposta = Metadata.getInstance<Select>('identificacao-atividade-cliente-cda-proposta');
        const localServico = Metadata.getInstance<Select>('identificacao-atividade-cliente-cda-local');
        const projeto = Metadata.getInstance<Select>('identificacao-atividade-cliente-cda-projeto');
        const infoAtividade = Metadata.getInstance<Grid>('cda-tek-grid');
        const fields = [representante, proposta, projeto, localServico];

        fields.forEach((dados) => {
            if (component.value) {
                dados.datasource.setFilter({
                    CDCLIENTE: component.datasource.currentRowValue.CDCLIENTE,
                });
                if (dados.label === 'Projeto') {
                    dados.datasource.setFilter({
                        CDCLIENTE: component.datasource.currentRowValue.CDCLIENTE,
                        CDOPERADOR: infoAtividade.datasource.currentRow.CDOPERADOR,
                        NRORG: component.datasource.currentRowValue.NRORG,
                    });
                }
                if (dados.label === 'Proposta') {
                    dados.datasource.setFilter({
                        CDCLIENTE: component.datasource.currentRowValue.CDCLIENTE,
                        CDFUNC: infoAtividade.datasource.currentRow.CDFUNC,
                    });
                }
                dados.disabled = false;
            } else {
                dados.disabled = true;
                dados.value = null;
            }
        });
    }

    public setParametrosTipoAtividade({ component }: any) {
        const proposta = Metadata.getInstance<Select>('identificacao-atividade-cliente-cda-proposta');
        const atividade = Metadata.getInstance<Select>('identificacao-atividade-cliente-cda-atividade');
        const infoAtividade = Metadata.getInstance<Grid>('cda-tek-grid');

        if (component.value) {
            atividade.datasource.setFilter({
                CDCLIENTE: component.datasource.currentRowValue.CDCLIENTE,
                NRORG: component.datasource.currentRowValue.NRORG,
                CDFUNC: infoAtividade.datasource.currentRow.CDFUNC,
                NRPROPOSFAS: proposta.datasource.currentRow.NRPROPOSFAS,
                NRVERPROPFAS: proposta.datasource.currentRow.NRVERPROPFAS,
                DTSERVPREST: infoAtividade.datasource.currentRow.DTSERVPREST,
            });
            atividade.disabled = false;
        } else {
            atividade.disabled = true;
            atividade.value = null;
        }
    }

    public setParametroInterlocutorProspect({ component }: any) {
        const interlocutor = Metadata.getInstance<Select>('identificacao-visita-prospect-cda-intelocutor-prospect');

        if (component.value) {
            interlocutor.datasource.setFilter({
                CDPROSPECT: component.datasource.currentRowValue.CDPROSPECT,
            });
            interlocutor.disabled = false;
        } else {
            interlocutor.disabled = true;
            interlocutor.value = null;
        }
    }

    public setParametroInterlocutorCliente({ component }: any) {
        const cliente = Metadata.getInstance<Select>('identificacao-relacionamento-cliente-cda-intelocutor');

        if (component.value) {
            cliente.datasource.setFilter({
                CDCLIENTE: component.datasource.currentRowValue.CDCLIENTE,
            });
            cliente.disabled = false;
        } else {
            cliente.disabled = true;
            cliente.value = null;
        }
    }

    public setParametrosContato() {
        const prospect = Metadata.getInstance<Select>('identificacao-visita-prospect-cda-prospect');
        const interlocutor = Metadata.getInstance<Select>('identificacao-visita-prospect-cda-intelocutor-prospect');
        const contato = Metadata.getInstance<Select>('contato-lancamento-cda-prospect');
        
        Metadata.getInstance<TextInput>('contato-lancamento-cda-telefone-intelocutor').value = interlocutor.datasource.currentRow.NRTEL1INPROS;
        Metadata.getInstance<TextInput>('contato-lancamento-cda-email-interlocutor').value = interlocutor.datasource.currentRow.DSEMAILIPROS;
        
        if (prospect.value) {
            contato.datasource.setFilter({
                NRPARCNEGOCIO: prospect.datasource.currentRow.NRPARCNEGOCIO,
            });
            contato.disabled = false;
        } else {
            contato.disabled = true;
            contato.value = null;
        }
    }

    public setParametrosContatoCliente() {
        const cliente = Metadata.getInstance<Select>('identificacao-relacionamento-cliente-cda');
        const interlocutor = Metadata.getInstance<Select>('identificacao-relacionamento-cliente-cda-intelocutor');
        const contato = Metadata.getInstance<Select>('contato-lancamento-cda-prospect');
        
        Metadata.getInstance<TextInput>('contato-lancamento-cda-telefone-intelocutor').value = interlocutor.datasource.currentRow.NRTEL1INCLIE;
        Metadata.getInstance<TextInput>('contato-lancamento-cda-email-interlocutor').value = interlocutor.datasource.currentRow.DSEMAILICLIE;
        
        if (cliente.value) {
            contato.datasource.setFilter({
                NRPARCNEGOCIO: cliente.datasource.currentRow.NRPARCNEGOCIO,
            });
            contato.disabled = false;
        } else {
            contato.disabled = true;
            contato.value = null;
        }
    }
    
    public addNewRow({ component }: IEventParam<TekGrid>) {
        const grid = Metadata.getInstance<TekGrid>('descricao-lacamento-cda-participantes-grid-temporario');
        const newId = grid.datasource.data.length + 1;
        component.addNewRow({ NRSERVPRESTPARTICIP: newId });
    }

    public calcularHorasServPrest() {
        const entrada = this.converterHoraEmNumero(Metadata.getInstance<ZdTextInput>('registro-de-horas-cda-hora-entrada').value);
        const saida = this.converterHoraEmNumero(Metadata.getInstance<ZdTextInput>('registro-de-horas-cda-hora-saida').value);
        const almoco = this.converterHoraEmNumero(Metadata.getInstance<ZdTextInput>('registro-de-horas-cda-hora-almoco').value);
        const horasTotais = saida - entrada;
        const horasServPrest = (horasTotais - almoco);
        Metadata.getInstance<ZdTextInput>('registro-de-horas-cda-horas-servico-prestado').value = this.converterNumeroEmHora(horasServPrest);
    }

    public converterHoraEmNumero(valor: any) {
        const hora = parseFloat(valor.substr(0, 2));
        const minutos = parseFloat(valor.substr(2, 4)) / 60;
        return hora + minutos;
    }

    public converterNumeroEmHora(valor: any) {
        const horas = Math.floor(valor);
        const minutos = Math.round((valor - horas) * 60);
        let valorFormatado = `${horas}${minutos}`;
        if (minutos < 10) {
            valorFormatado = `${horas}0${minutos}`;
        } if (horas < 10) {
            valorFormatado = `0${valorFormatado}`;
        }
        return valorFormatado;
    }

    public calcularHorasServFaturado() {
        const horasServPrest = Metadata.getInstance<ZdTextInput>('registro-de-horas-cda-horas-servico-prestado').value;
        const deslocamentoFaturado = Metadata.getInstance<ZdTextInput>('registro-de-horas-cda-deslocamento-faturado').value;
        const horasServFaturado = this.converterHoraEmNumero(horasServPrest) + this.converterHoraEmNumero(deslocamentoFaturado);
        Metadata.getInstance<ZdTextInput>('registro-de-horas-cda-horas-servico-faturado').value = this.converterNumeroEmHora(horasServFaturado);
    }

    public defineGridHorasNaoFaturadas() {
        const gridPrincipal = Metadata.getInstance<TekGrid>('registro-de-horas-cda-horas-nao-faturadas-grid');
        const gridInterno = Metadata.getInstance<TekGrid>('registro-de-horas-cda-horas-nao-faturadas-grid-temporario');

        gridInterno.datasource.data = [];
        (gridInterno.datasource as MemoryDatasource).allData = [];

        gridPrincipal.datasource.data.forEach((element: any) => {
            const dados: any = {
                NRJUSTHORASNAOFATUCDA: element.NRJUSTHORASNAOFATUCDA,
                DSJUSTHORASNAOFATUCDA: element.DSJUSTHORASNAOFATUCDA,
            };
            gridInterno.datasource.post(dados);
        });
        gridInterno.datasource.get();
    }

    public calcularHorasNaoFaturadas({ component, event }: IEventParam<TekGrid>) {
        event?.preventDefault();
        let totalhorasNaoFaturadas = 0;
        const horasNaoFaturadas = component.getEditedRows();

        horasNaoFaturadas.forEach((element: any) => {
            totalhorasNaoFaturadas += this.converterHoraEmNumero(element.HORASNAOFATUCDA);
        });

        component.saveEditedRows();
        component.datasource.get();

        Metadata.getInstance<ZdTextInput>('registro-de-horas-cda-horas-nao-faturadas').value = this.converterNumeroEmHora(totalhorasNaoFaturadas);
    }

    public incluiAtividadeNoMesmoDia() {
        if (this.currentRow.IDSERVPREST !== '' || this.currentRow.IDSERVPREST !== null) {
            this.currentRow.IDSERVPREST = '';
            this.currentRow.IDSERVPREST_IN_GRID = '';
        }
        this.montarInformacoesAtividade();
    }

    /* public async inserirAtividadeCda() {
        const grid = Metadata.getInstance<TekGrid>('cda-tek-grid');
        const idservprest = Metadata.getInstance<Select>('tipoLacamento-atividade-cda-tipolacamento').value;
        const nrorg = grid.datasource.currentRow.NRORG;
        const dtservprest = grid.datasource.currentRow.DTSERVPREST;
        const dsreferencia = grid.datasource.currentRow.DSREFERENCIA;
        const cdfunc = grid.datasource.currentRow.CDFUNC;
        const cdoperador = grid.datasource.currentRow.CDOPERADOR;
        const cdempresa = grid.datasource.currentRow.CDEMPRESA;
        const nrservprest = grid.datasource.currentRow.NRSERVPREST;
        const nrlicencauso = Metadata.getInstance<Select>('identificacao-atividade-cliente-cda-local').value;
        const cdprojeto = Metadata.getInstance<Select>('identificacao-atividade-cliente-cda-projeto').value;
        const cdtiposerv = Metadata.getInstance<Select>('identificacao-atividade-cliente-cda-atividade').value;
        const idsitservprest = grid.datasource.currentRow.IDSITSERVPREST;
        const nrproposfas = Metadata.getInstance<Select>('identificacao-atividade-cliente-cda-proposta').value;
        const participantes = Metadata.getInstance<TekGrid>('descricao-lacamento-cda-participantes-grid-temporario').datasource.data;
        const dsevolcont = Metadata.getInstance<Textarea>('contato-lancamento-cda-descricao').value;
        const dadoscontato = Metadata.getInstance<Select>('contato-lancamento-cda-prospect');
        const dadosprospect = Metadata.getInstance<Select>('identificacao-visita-prospect-cda-prospect');
        const dadosrepresentate = Metadata.getInstance<Select>('identificacao-atividade-cliente-cda-representante');
        const dadosmotievocon = Metadata.getInstance<Select>('contato-lancamento-cda-motivo-evolucao');
        let nrmotivoexcefreq = null;
        let cdinteclie = null;
        let nmintcliente = null;
        let cdprospect = null;
        let cdintepros = null;
        let nrparcnegocio = null;
        let nrcontato = null;
        let cdcliente = null;
        let nrverproposfas = null;
        let cdmontcont = null;
        let cdsistema = null;
        let cdmotievocon = null;
        
        switch (idservprest) {
            case 'ATIVIDADE_CLIENTE':
                cdcliente = Metadata.getInstance<Select>('identificacao-atividade-cliente-cda-cliente').datasource.currentRow.CDCLIENTE;
                cdinteclie = dadosrepresentate.datasource.currentRow.CDINTECLIE;
                nmintcliente = dadosrepresentate.datasource.currentRow.NMINTECLIE;
                nrverproposfas = Metadata.getInstance<Select>('identificacao-atividade-cliente-cda-proposta').datasource.currentRow.NRVERPROPFAS;
                break;
            case 'VISITA_PROSPECT':
                cdprospect = dadosprospect.datasource.currentRow.CDPROSPECT;
                nrparcnegocio = dadosprospect.datasource.currentRow.NRPARCNEGOCIO;
                if (dadoscontato.value !== null) {
                    nrcontato = dadoscontato.datasource.currentRow.NRCONTATO;
                }
                cdmontcont = Metadata.getInstance<Select>('contato-lancamento-cda-intelocutor-motivo').datasource.currentRow.CODIGO;
                cdsistema = Metadata.getInstance<Select>('contato-lancamento-cda-intelocutor-sistema').datasource.currentRow.CDSISTEMA;
                cdmotievocon = dadosmotievocon.datasource.currentRow.CDMOTIEVOCON;
                cdintepros = Metadata.getInstance<Select>('identificacao-visita-prospect-cda-intelocutor-prospect').datasource.currentRow.CDINTEPROS;
                break;
            case 'RELACIONAMENTO_CLIENTE':
                cdcliente = Metadata.getInstance<Select>('identificacao-relacionamento-cliente-cda').datasource.currentRow.CDCLIENTE;
                if (dadoscontato.value !== null) {
                    nrcontato = dadoscontato.datasource.currentRow.NRCONTATO;
                }
                cdmontcont = Metadata.getInstance<Select>('contato-lancamento-cda-intelocutor-motivo').datasource.currentRow.CODIGO;
                cdsistema = Metadata.getInstance<Select>('contato-lancamento-cda-intelocutor-sistema').datasource.currentRow.CDSISTEMA;
                cdmotievocon = dadosmotievocon.datasource.currentRow.CDMOTIEVOCON;
                break;
            case 'FALTA_JUSTIFICADA':
                nrmotivoexcefreq = Metadata.getInstance<Select>('justificativa-lacamento-cda').datasource.currentRow.NRMOTIVOEXCEFREQ;
                break;
            case 'AFASTAMENTO_INSS':
                nrmotivoexcefreq = Metadata.getInstance<Select>('justificativa-lacamento-afastamentoinss-cda').datasource.currentRow.NRMOTIVOEXCEFREQ;
                break;
            default:
                break;
        }
        
        LoadingService.show();
        Http.post('/inserirAtividadeCda', {
            IDSERVPREST: idservprest,
            NRMOTIVOEXCEFREQ: nrmotivoexcefreq,
            CDCLIENTE: cdcliente,
            CDINTECLIE: cdinteclie,
            CDPROSPECT: cdprospect,
            CDINTEPROS: cdintepros,
            NMINTCLIENTE: nmintcliente,
            NRLICENCAUSO: nrlicencauso,
            CDPROJETO: cdprojeto,
            CDTIPOSERV: cdtiposerv,
            CDFUNC: cdfunc,
            DSREFERENCIA: dsreferencia,
            DTSERVPREST: dtservprest,
            CDEMPRESA: cdempresa,
            IDSITSERVPREST: idsitservprest,
            NRPROPOSFAS: nrproposfas,
            NRSEQUCHT: null,
            NRSERVPREST: nrservprest,
            NRVERPROPFAS: nrverproposfas,
            NRCONTATO: nrcontato,
            NRPARCNEGOCIO: nrparcnegocio,
            DTHREVOLCONT: null,
            CDFILIAL: null,
            DTENTRADA: null,
            NRORG: nrorg,
            NRORGINCLUSAO: nrorg,
            CDOPERINCLUSAO: cdoperador,
            DTINCLUSAO: null,
            NRORGULTATU: null,
            CDOPERULTATU: null,
            DTULTATU: null,
            IDATIVO: null,
            NRSERVCONT: null,
            NRSEQAGESERV: null,
            CDMOTICONT: cdmontcont,
            CDSISTEMA: cdsistema,
            CDMOTIEVOCON: cdmotievocon,
            DSEVOLCONT: dsevolcont,
            PARTICIPANTES: participantes,
        }).then(() => {
            Utilities.showSuccessMessage();
            grid.datasource.get();
            this.voltarPaginaInicial();
        }).catch((error) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    } */

    public gerarModeloDocumento() {
        const grid = Metadata.getInstance<TekGrid>('cda-tek-grid');
        this.verificaIdiomaDoc();
        console.warn(grid);
    }

    public verificaIdiomaDoc() {
        const idioma = Metadata.getInstance<Select>('FORM-GERA-CDA-CDIDIOM').datasource.currentRow.CDIDIOM;
        Http.get(`/getModeloDocumentoPadraoCda?CDIDIOM=${idioma}`).then((response: IDictionary) => {
            if (response.data.data[0] == null) {
                Utilities.alertMessage('Não existe documento padrão para o idioma selecionado.', 'error');
            }
            this.fecharModalGeraDoc();
        });
    }
}
